package Acme::Tests::Perl;
use Acme::Tests -Base;
our $VERSION = '0.01';

__DATA__
Which one is an author id on CPAN ?
  (1) jhh
  (2) jhi
  (3) jhj
  (4) jhk
Ans: 2
----
Which debugger does lwall use ?
  (1) perl -d
  (2) gdb
  (3) American Heritage Dictionary
  (4) printf
Ans: 4
----
What is the meaning of Ponie in Perl6?
  (1) The animal that eats carrot.
  (2) The codename of Perl6
  (3) The Perl 5 interpreter
  (4) The replacement of /usr/bin/perl
Ans: 3
----
__END__
=head1 NAME

Acme::Tests::Perl - Test you about Perl

=head1 COPYRIGHT

Copyright 2005,2006 by Kang-min Liu <gugod@gugod.org>.

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

See <http://www.perl.com/perl/misc/Artistic.html>

=cut
